@@ -1,6 +1,4 @@
-/*   $Source: /var/local/cvs/gasnet/gasnet_mmap.c,v $
- *     $Date: 2013/09/25 02:16:26 $
- * $Revision: 1.130.2.1 $
+/*   $Source: bitbucket.org:berkeleylab/gasnet.git/gasnet_mmap.c $
  * Description: GASNet memory-mapping utilities
  * Copyright 2002, Dan Bonachea <bonachea@cs.berkeley.edu>
  * Terms of use are as specified in license.txt
@@ -14,13 +12,13 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#if defined(GASNETI_MMAP_OR_SYSV) && !defined(HAVE_MMAP)
-  /* Ensure PSHM-over-SYSV support never actually calls mmap() */
+#if defined(GASNETI_MMAP_OR_PSHM) && !defined(HAVE_MMAP)
+  /* Ensure PSHM over SYSV or GHEAP never actually call mmap() */
   #define mmap %%%ERROR__GASNet_does_not_support_mmap_in_this_configuration%%%
   #define munmap %%%ERROR__GASNet_does_not_support_munmap_in_this_configuration%%%
 #endif
 
-#ifdef GASNETI_MMAP_OR_SYSV
+#ifdef GASNETI_MMAP_OR_PSHM
  #if GASNET_PSHM && !defined(_POSIX_C_SOURCE) && PLATFORM_OS_SOLARIS
   #define _POSIX_C_SOURCE 200112L /* Required for shm_{open,unlink} decls */
   #include <sys/mman.h>
@@ -51,23 +49,8 @@
 
 #if !HAVE_MMAP
   /* Skip the following platform checks */
-#elif PLATFORM_OS_IRIX
-  #ifdef MAP_SGI_ANYADDR /* allow mmap to use 'reserved' 256MB region on O2k */
-    #define GASNETI_MMAP_FLAGS (MAP_PRIVATE | MAP_SGI_ANYADDR | MAP_AUTORESRV)
-  #else
-    #define GASNETI_MMAP_FLAGS (MAP_PRIVATE | MAP_AUTORESRV)
-  #endif
-  #define GASNETI_MMAP_FILE "/dev/zero"
-#elif PLATFORM_ARCH_CRAYX1
-  #define GASNETI_MMAP_FLAGS (MAP_PRIVATE | MAP_AUTORESRV)
-  #define GASNETI_MMAP_FILE "/dev/zero"
-#elif PLATFORM_ARCH_CRAYT3E
-  #error mmap not supported on Cray-T3E
 #elif PLATFORM_OS_CYGWIN
   #error mmap not supported on Cygwin - it doesnt work properly
-#elif PLATFORM_OS_HPUX
-  #define GASNETI_MMAP_FLAGS (MAP_ANONYMOUS | MAP_NORESERVE | MAP_PRIVATE)
-  #define GASNETI_MMAP_NOTFIXED_FLAG MAP_VARIABLE
 #elif PLATFORM_ARCH_MIC
   #define GASNETI_MMAP_FLAGS (MAP_ANONYMOUS | MAP_PRIVATE | MAP_POPULATE | MAP_HUGETLB)
 #endif
@@ -102,8 +85,8 @@
   #define GASNETI_MMAP_NOTFIXED_FLAG 0
 #endif
 
-#if GASNET_PSHM && (PLATFORM_OS_BGP || PLATFORM_OS_BGQ || PLATFORM_OS_CYGWIN)
-  /* BG/P and /Q: MAP_FIXED is ignored for fd obtained from pshm_open() */
+#if GASNET_PSHM && (PLATFORM_OS_BGQ || PLATFORM_OS_CYGWIN)
+  /* BG/Q: MAP_FIXED is ignored for fd obtained from pshm_open() */
   /* CYGWIN: may not honor the address passed to shmat() */
   #define GASNETI_PSHM_MAP_FIXED_IGNORED 1
 #endif
@@ -125,9 +108,13 @@ static void *gasneti_mmap_internal(void *segbase, uintptr_t segsize) {
   #endif
 
   t1 = gasneti_ticks_now();
+#if defined(GASNETI_USE_HUGETLBFS)
+  ptr = gasneti_huge_mmap(segbase, segsize);
+#else
   ptr = mmap(segbase, segsize, (PROT_READ|PROT_WRITE), 
       (GASNETI_MMAP_FLAGS | (segbase==NULL?GASNETI_MMAP_NOTFIXED_FLAG:GASNETI_MMAP_FIXED_FLAG)), 
       gasneti_mmapfd, 0);
+#endif
   mmap_errno = errno;
   t2 = gasneti_ticks_now();
 
@@ -184,6 +171,10 @@ extern void *gasneti_mmap(uintptr_t segsize) {
 #elif defined(GASNETI_PSHM_XPMEM)
   static gasneti_xpmem_segid_t *gasneti_pshm_segids = NULL;
   static gasneti_xpmem_apid_t *gasneti_pshm_apids = NULL;
+#elif defined(GASNETI_PSHM_GHEAP)
+  static void* gasneti_pshm_valloc(size_t size);
+  static void gasneti_pshm_vfree(void *addr);
+  static void **gasneti_pshm_segaddrs = NULL;
 #endif
 
 static char *gasneti_pshm_tmpfile = NULL;
@@ -445,48 +436,12 @@ extern void gasneti_huge_munmap(void *addr, uintptr_t size) {
 
 #if GASNET_PSHM
 
-#if defined(PLATFORM_OS_BGQ) /* must delay close until unmap() */
-  static struct {
-    void *addr;
-    int fd;
-  } *gasneti_addr2fd = NULL;
-  static void gasneti_addr2fd_add(void *addr, int fd) {
-    int i;
-    if (NULL == gasneti_addr2fd) {
-       gasneti_addr2fd = gasneti_calloc(1+gasneti_pshm_nodes, sizeof(*gasneti_addr2fd));
-    }
-    for (i=0; i<=gasneti_pshm_nodes; ++i) {
-      if (gasneti_addr2fd[i].addr == NULL) {
-        gasneti_addr2fd[i].addr = addr;
-        gasneti_addr2fd[i].fd = fd;
-        return;
-      }
-    }
-    gasneti_fatalerror("addr2fd table is full");
-  }
-  static int gasneti_addr2fd_del(void *addr) {
-    int i;
-    for (i=0; i<=gasneti_pshm_nodes; ++i) {
-      if (gasneti_addr2fd[i].addr == addr) {
-        gasneti_addr2fd[i].addr = NULL;
-        return gasneti_addr2fd[i].fd;
-      }
-    }
-    gasneti_fatalerror("address not found in addr2fd table");
-  }
-#endif /* BGQ */
-
 static void gasneti_pshm_unlink(int pshm_rank);
 
 /* create the object/region/segment and return its address */
 static void * gasneti_pshm_mmap(int pshm_rank, void *segbase, size_t segsize) {
-#if defined(PLATFORM_OS_BGP) || defined(PLATFORM_OS_BGQ)
-  /* shm_unlink() is apparently a no-op on BG/P and earlier driver versions on /Q */
-  const int create = ((pshm_rank == gasneti_pshm_nodes) && !gasneti_pshm_mynode);
-#else
   const int create = (pshm_rank == gasneti_pshm_mynode) ||
                      ((pshm_rank == gasneti_pshm_nodes) && !gasneti_pshm_mynode);
-#endif
   void * ptr = MAP_FAILED;
 
 #if defined(GASNETI_PSHM_SYSV)
@@ -526,13 +481,6 @@ static void * gasneti_pshm_mmap(int pshm_rank, void *segbase, size_t segsize) {
           fd = shm_open(filename, flags, S_IRUSR | S_IWUSR);
         } while ((fd == -1) && (errno == EEXIST) && retries_remain--);
       }
-    #elif defined(PLATFORM_OS_BGQ)
-      /* XXX: configure or compile time way to know? */
-      if ((fd == -1) && (errno == ENOENT) && (pshm_rank == gasneti_pshm_mynode)) {
-        /* We didn't use O_CREAT+O_EXCL on the first try, because shm_unlink()
-         * does nothing prior to V1R2M1.  So, try again with those flags. */
-        fd = shm_open(filename, flags | O_CREAT | O_EXCL, S_IRUSR | S_IWUSR);
-      }
     #endif
   #else
     #error
@@ -548,12 +496,6 @@ static void * gasneti_pshm_mmap(int pshm_rank, void *segbase, size_t segsize) {
     ptr = mmap(segbase, segsize, (PROT_READ|PROT_WRITE), mmap_flags, fd, 0);
   }
 
- #if defined(PLATFORM_OS_BGQ)
-  /* must delay close() untile just before munmap() */
-  if (ptr != MAP_FAILED) {
-    gasneti_addr2fd_add(ptr, fd);
-  } else
- #endif
   {
     const int save_errno = errno;
     (void) close(fd);
@@ -578,6 +520,12 @@ static void * gasneti_pshm_mmap(int pshm_rank, void *segbase, size_t segsize) {
       ptr = xpmem_attach(xa, segsize, segbase);
     }
   }
+#elif defined(GASNETI_PSHM_GHEAP)
+  if (create) {
+    ptr = gasneti_pshm_valloc(segsize);
+  } else {
+    ptr = gasneti_pshm_segaddrs[pshm_rank];
+  }
 #else
   #error
 #endif
@@ -606,6 +554,8 @@ static void gasneti_pshm_munmap(void *segbase, uintptr_t segsize) {
  #else
   gasneti_munmap(segbase, segsize);
  #endif
+#elif defined(GASNETI_PSHM_GHEAP)
+  gasneti_pshm_vfree(segbase);
 #else
   #error
 #endif
@@ -625,6 +575,8 @@ static void gasneti_munmap_remote(gasnet_node_t pshm_rank, void *segbase, uintpt
 #elif defined(GASNETI_PSHM_XPMEM)
   xpmem_detach(segbase);
   xpmem_release(gasneti_pshm_apids[pshm_rank]);
+#elif defined(GASNETI_PSHM_GHEAP)
+ /* Nothing to do here */
 #else
   #error
 #endif
@@ -640,6 +592,8 @@ void gasneti_export_segment(void *segbase, uintptr_t segsize) {
     fprintf(stderr, "xpmem_make() failed:%s\n", strerror(errno));
   }
   gasneti_pshmnet_bootstrapExchange(gasneti_request_pshmnet, &segid, sizeof(segid), gasneti_pshm_segids);
+#elif defined(GASNETI_PSHM_GHEAP)
+  gasneti_pshmnet_bootstrapExchange(gasneti_request_pshmnet, &segbase, sizeof(segbase), gasneti_pshm_segaddrs);
 #else
   /* empty */
 #endif
@@ -665,7 +619,7 @@ static void gasneti_pshm_unlink(int pshm_rank){
 #elif defined(GASNETI_PSHM_POSIX)
   const char *filename = gasneti_pshmname[pshm_rank];
   (void)shm_unlink(filename);
-#elif defined(GASNETI_PSHM_XPMEM)
+#elif defined(GASNETI_PSHM_XPMEM) || defined(GASNETI_PSHM_GHEAP)
   /* Nothing to do */
 #else
   #error
@@ -678,7 +632,9 @@ static void gasneti_pshm_unlink(int pshm_rank){
  */
 static void gasneti_unlink_segments(void) {
   gasneti_pshmnet_bootstrapBarrier();
-#if !defined(GASNETI_PSHM_XPMEM)
+#if defined(GASNETI_PSHM_XPMEM) || defined(GASNETI_PSHM_GHEAP)
+  /* Nothing to do because gasneti_pshm_unlink() is a no-op */
+#else
   gasneti_pshm_unlink(gasneti_pshm_mynode);
   gasneti_pshmnet_bootstrapBarrier();
 #endif
@@ -706,15 +662,14 @@ static void gasneti_cleanup_shm(void) {
     gasneti_free(gasneti_pshmname);
     gasneti_pshmname = NULL;
   }
-  #if defined(PLATFORM_OS_BGQ)
-    gasneti_free(gasneti_addr2fd);
-    gasneti_addr2fd = NULL;
-  #endif
 #elif defined(GASNETI_PSHM_XPMEM)
   gasneti_free(gasneti_pshm_segids);
   gasneti_pshm_segids = NULL;
   gasneti_free(gasneti_pshm_apids);
   gasneti_pshm_apids = NULL;
+#elif defined(GASNETI_PSHM_GHEAP)
+  gasneti_free(gasneti_pshm_segaddrs);
+  gasneti_pshm_segaddrs = NULL;
 #else
   #error
 #endif
@@ -867,6 +822,32 @@ extern void *gasneti_mmap_vnet(uintptr_t size, gasneti_bootstrapExchangefn_t exc
       ptr = gasneti_mmap_shared_internal(gasneti_pshm_nodes, NULL, size, 1);
     }
   }
+  #elif defined(GASNETI_PSHM_GHEAP)
+  {
+    /* Initialization */
+    gasneti_pshm_segaddrs = gasneti_malloc(sizeof(void*) * (gasneti_pshm_nodes + 1));
+
+    /* First in each supernode creates the segment */
+    if (gasneti_pshm_mynode == 0) {
+      ptr = gasneti_mmap_shared_internal(gasneti_pshm_nodes, NULL, size, 1);
+      if (ptr != MAP_FAILED) {
+        memset(ptr, 0, size);
+      }
+    }
+    
+    /* Conduit's exchangefn is used as a supernode-scoped bcast to
+     * communicate the segment addresses alocated by the firsts */
+    { void **exchg = gasneti_malloc(gasneti_nodes * sizeof(ptr));
+      (*exchangefn)(&ptr, sizeof(ptr), exchg);
+      gasneti_pshm_segaddrs[gasneti_pshm_nodes] = exchg[gasneti_pshm_firstnode];
+      gasneti_free(exchg);
+    }
+
+    /* Non-first nodes attach */
+    if (gasneti_pshm_mynode != 0) {
+      ptr = gasneti_mmap_shared_internal(gasneti_pshm_nodes, NULL, size, 1);
+    }
+  }
   #else
     #error
   #endif
@@ -890,19 +871,6 @@ extern void gasneti_munmap(void *segbase, uintptr_t segsize) {
   gasneti_tick_t t1, t2;
   gasneti_assert(segsize > 0);
   t1 = gasneti_ticks_now();
-    #if 0 && PLATFORM_OS_TRU64 /* doesn't seem to help */
-      /* invalidate the pages before unmap to avoid write-back penalty */
-      if (madvise(segbase, segsize, MADV_DONTNEED))
-        gasneti_fatalerror("madvise("GASNETI_LADDRFMT",%lu) failed: %s\n",
-	        GASNETI_LADDRSTR(segbase), (unsigned long)segsize, strerror(errno));
-      if (msync(segbase, segsize, MS_INVALIDATE))
-        gasneti_fatalerror("msync("GASNETI_LADDRFMT",%lu) failed: %s\n",
-	        GASNETI_LADDRSTR(segbase), (unsigned long)segsize, strerror(errno));
-    #endif
-    #if GASNET_PSHM && defined(PLATFORM_OS_BGQ)
-      /* we delayed the close() until now */
-      close(gasneti_addr2fd_del(segbase));
-    #endif
     if (munmap(segbase, segsize) != 0) 
       gasneti_fatalerror("munmap("GASNETI_LADDRFMT",%lu) failed: %s\n",
 	      GASNETI_LADDRSTR(segbase), (unsigned long)segsize, strerror(errno));
@@ -1001,7 +969,7 @@ static gasnet_seginfo_t _gasneti_mmap_segment_search_inner(uintptr_t maxsz) {
     si.size = maxsz;
     mmaped = 1;
   } else { /* use a search to find largest possible */
-    #if PLATFORM_OS_TRU64
+    #if 0
       /* linear descending search best on systems with 
          fast mmap-failed and very slow unmap and/or mmap-succeed */
       si = gasneti_mmap_lineardesc_segsrch(maxsz);
@@ -1068,7 +1036,7 @@ extern gasnet_seginfo_t gasneti_mmap_segment_search(uintptr_t maxsz) {
 }
 
 /* ------------------------------------------------------------------------------------ */
-#endif /* GASNETI_MMAP_OR_SYSV */
+#endif /* GASNETI_MMAP_OR_PSHM */
 
 #if defined(GASNETI_MMAP_MAX_SIZE)
   GASNETI_IDENT(gasneti_IdentString_DefaultMaxSegsize, 
@@ -1109,14 +1077,14 @@ uintptr_t _gasneti_max_segsize(uint64_t configure_val) {
 #if !GASNET_SEGMENT_EVERYTHING
 /* mmap-based segment init/attach */
 static gasnet_seginfo_t gasneti_segment = {0,0}; /* local segment info */
-#ifdef GASNETI_MMAP_OR_SYSV
+#ifdef GASNETI_MMAP_OR_PSHM
 static uintptr_t gasneti_myheapend = 0; /* top of my malloc heap */
 static uintptr_t gasneti_maxheapend = 0; /* top of max malloc heap */
 static uintptr_t gasneti_maxbase = 0; /* start of segment overlap region */
 #if GASNET_PSHM
 static gasnet_seginfo_t *gasneti_remote_segments;
 #endif /* GASNET_PSHM */
-#endif /* GASNETI_MMAP_OR_SYSV */
+#endif /* GASNETI_MMAP_OR_PSHM */
 
 typedef struct {
   gasnet_seginfo_t seginfo;
@@ -1125,7 +1093,7 @@ typedef struct {
 } gasneti_segexch_t;
 static gasneti_segexch_t *gasneti_segexch = NULL; /* exchanged segment information */
 
-#ifdef GASNETI_MMAP_OR_SYSV
+#ifdef GASNETI_MMAP_OR_PSHM
 /* perform a coordinated mmap probe to determine the max memory
     that can be mmap()ed while considering multiple GASNet nodes
     per shared memory node
@@ -1156,9 +1124,7 @@ uintptr_t gasneti_mmapLimit(uintptr_t localLimit, uint64_t sharedLimit,
   gasneti_assert(gasneti_nodemap);
 
   /* Apply system-dependent defaults, if any */
-#if defined(GASNETI_HAVE_BGP_INLINES) && 0 /* Not implemented */
-    /* XXX: should be able to do something like done for BG/Q, below */
-#elif defined(GASNETI_HAVE_BGQ_INLINES)
+#if defined(GASNETI_HAVE_BGQ_INLINES)
   if ((localLimit == (uintptr_t)-1) || (sharedLimit == (uint64_t)-1)) {
     const uint64_t nodemem = gasneti_getPhysMemSz(1); /* sysconf() reports phys mem for full node */
     const uint64_t safemem = (nodemem * 4) / 5; /* 80% as a safety margin (but just a guess) */
@@ -1257,6 +1223,11 @@ uintptr_t gasneti_mmapLimit(uintptr_t localLimit, uint64_t sharedLimit,
       maxsz = GASNETI_PAGE_ALIGNDOWN(maxsz);
 
 #if GASNET_PSHM
+    #if defined(GASNETI_PSHM_GHEAP)
+      /* We don't consue any additional virtual address space for each segment.
+       * So, the coordnation below is not required.
+       */
+    #else
       /* The probe completed has determined how much memory we can map.
        * However, we now need to be sure that multiple segments will fit.
        * The limit could be, for instance, due to
@@ -1305,6 +1276,7 @@ uintptr_t gasneti_mmapLimit(uintptr_t localLimit, uint64_t sharedLimit,
       /* Unlink the shared segments to prevent leaks (they are recreated in segmentInit) */
       /* XXX: redundant? */
       gasneti_unlink_segments();
+    #endif
 #endif
     }
 
@@ -1319,7 +1291,7 @@ uintptr_t gasneti_mmapLimit(uintptr_t localLimit, uint64_t sharedLimit,
 #endif
   return maxsz;
 }
-#endif /* GASNETI_MMAP_OR_SYSV */
+#endif /* GASNETI_MMAP_OR_PSHM */
 
 /* do the work necessary for initing a standard segment map in arbitrary memory 
      uses mmap if available, or malloc otherwise
@@ -1348,7 +1320,7 @@ void gasneti_segmentInit(uintptr_t localSegmentLimit,
   if (localSegmentLimit != (uintptr_t)-1) 
     localSegmentLimit = GASNETI_PAGE_ALIGNDOWN(localSegmentLimit);
 
-  #ifdef GASNETI_MMAP_OR_SYSV
+  #ifdef GASNETI_MMAP_OR_PSHM
   { gasneti_segexch_t se;
     int i;
 
@@ -1426,7 +1398,7 @@ void gasneti_segmentInit(uintptr_t localSegmentLimit,
       gasneti_maxbase = maxbase;
       #if GASNET_ALIGNED_SEGMENTS
        /* BG/[PQ] would incorrectly probe the I/O node */
-       #if !defined(PLATFORM_OS_BGP) && !defined(PLATFORM_OS_BGQ)
+       #if !defined(PLATFORM_OS_BGQ)
         if (gasneti_nodes > 1) { 
           /* bug 2067 - detect if the compute nodes are using Linux's 'intentional VM space randomization'
            * security feature, which is known to break GASNET_ALIGNED_SEGMENTS, esp at large scale
@@ -1478,7 +1450,7 @@ void gasneti_segmentInit(uintptr_t localSegmentLimit,
       #endif
     }
   }
-  #else /* !GASNETI_MMAP_OR_SYSV */
+  #else /* !GASNETI_MMAP_OR_PSHM */
     #if GASNET_ALIGNED_SEGMENTS && !GASNET_CONDUIT_SMP
       #error bad config: dont know how to provide GASNET_ALIGNED_SEGMENTS when !HAVE_MMAP
     #endif
@@ -1525,7 +1497,7 @@ void gasneti_segmentAttachLocal(uintptr_t segsize, uintptr_t minheapoffset,
 
   bias = GASNETI_SEGMENT_DISALIGN_BIAS * (gasneti_mynode%2);
 
-  #ifdef GASNETI_MMAP_OR_SYSV
+  #ifdef GASNETI_MMAP_OR_PSHM
   { /* TODO: this assumes heap grows up */
     uintptr_t topofheap;
     #if GASNET_ALIGNED_SEGMENTS
@@ -1616,7 +1588,7 @@ void gasneti_segmentAttachLocal(uintptr_t segsize, uintptr_t minheapoffset,
       }
     }
   }
-  #else /* !GASNETI_MMAP_OR_SYSV */
+  #else /* !GASNETI_MMAP_OR_PSHM */
     /* for the T3E, and other platforms which don't support mmap */
     segbase = gasneti_malloc_allowfail(segsize + GASNET_PAGESIZE + bias);
     while (!segbase) {
@@ -1628,7 +1600,7 @@ void gasneti_segmentAttachLocal(uintptr_t segsize, uintptr_t minheapoffset,
       segbase = (void *)GASNETI_PAGE_ALIGNUP(segbase);
       segbase = (void *)(((uintptr_t)segbase)+bias);
     }
-  #endif /* GASNETI_MMAP_OR_SYSV */
+  #endif /* GASNETI_MMAP_OR_PSHM */
   gasneti_assert(((uintptr_t)segbase) % GASNET_PAGESIZE == 0);
   gasneti_assert(segsize % GASNET_PAGESIZE == 0);
   GASNETI_TRACE_PRINTF(C, ("Final segment: segbase="GASNETI_LADDRFMT"  segsize=%lu",
@@ -2198,3 +2170,21 @@ void gasneti_auxseg_attach(void) {
   gasneti_leak(gasneti_auxseg_alignedsz);
 }
 /* ------------------------------------------------------------------------------------ */
+#if defined(GASNETI_PSHM_GHEAP)
+  /* Access to unwrapped malloc/free */
+  #undef malloc
+  #undef free
+  static void *gasneti_pshm_valloc(size_t size) {
+    void *result;
+    /* TODO: configure probe for posix_memalign() and alternatives when missing? */
+    if (0 != posix_memalign(&result, GASNETI_PSHMNET_PAGESIZE, size)) {
+      result = MAP_FAILED;
+    }
+    return result;
+  }
+  static void gasneti_pshm_vfree(void *addr) {
+    /* TODO: alternatives as above? */
+    free(addr);
+  }
+#endif
+/* ------------------------------------------------------------------------------------ */
