@@ -1,6 +1,4 @@
-/*   $Source: /var/local/cvs/gasnet/ibv-conduit/gasnet_extended.c,v $
- *     $Date: 2013/08/24 05:11:11 $
- * $Revision: 1.103 $
+/*   $Source: bitbucket.org:berkeleylab/gasnet.git/ibv-conduit/gasnet_extended.c $
  * Description: GASNet Extended API over IB Verbs Implementation
  * Copyright 2002, Dan Bonachea <bonachea@cs.berkeley.edu>
  * Terms of use are as specified in license.txt
@@ -344,44 +342,9 @@ void gasneti_iop_markdone(gasneti_iop_t *iop, unsigned int noperations, int isge
   ===============
 */
 
-/* Use reference implementation of get/put/memset in terms of AMs */
-/* NOTE: Barriers, Collectives, VIS may use GASNETE_USING_REF_* in algorithm selection */
-#define GASNETE_USING_REF_EXTENDED_GET_BULK 0    /* conduit-specific via RDMA */
-#define GASNETE_USING_REF_EXTENDED_PUT_BULK 0    /* conduit-specific via RDMA */
-#define GASNETE_USING_REF_EXTENDED_PUT      0    /* conduit-specific via RDMA */
-#define GASNETE_USING_REF_EXTENDED_MEMSET   1
-
-/* in order to use reference memset with our conduit-specific eop */
-#define GASNETE_AMREF_USE_MARKDONE          1
-
-#if GASNETE_USING_REF_EXTENDED_GET_BULK
-#define GASNETE_BUILD_AMREF_GET_HANDLERS 1
-#define GASNETE_BUILD_AMREF_GET_BULK     1
-#define gasnete_amref_get_nb_bulk   gasnete_get_nb_bulk
-#define gasnete_amref_get_nbi_bulk  gasnete_get_nbi_bulk
-#endif
-
-#if GASNETE_USING_REF_EXTENDED_PUT_BULK
-#define GASNETE_BUILD_AMREF_PUT_HANDLERS 1
-#define GASNETE_BUILD_AMREF_PUT_BULK     1
-#define gasnete_amref_put_nb_bulk   gasnete_put_nb_bulk
-#define gasnete_amref_put_nbi_bulk  gasnete_put_nbi_bulk
-#endif
-
-#if GASNETE_USING_REF_EXTENDED_PUT
-#define GASNETE_BUILD_AMREF_PUT_HANDLERS 1
-#define GASNETE_BUILD_AMREF_PUT     1
-#define gasnete_amref_put_nb        gasnete_put_nb
-#define gasnete_amref_put_nbi       gasnete_put_nbi
-#endif
-
-#if GASNETE_USING_REF_EXTENDED_MEMSET
-#define GASNETE_BUILD_AMREF_MEMSET_HANDLERS 1
-#define GASNETE_BUILD_AMREF_MEMSET  1
-#define gasnete_amref_memset_nb     gasnete_memset_nb
-#define gasnete_amref_memset_nbi    gasnete_memset_nbi
-#endif
-
+/* Use reference implementation of memset in terms of AMs.
+ * Configuration appears in gasnet_extended_fwd.h
+ */
 #include "gasnet_extended_amref.c"
 
 /* ------------------------------------------------------------------------------------ */
