@@ -1,6 +1,4 @@
-#ifdef __BERKELEY_UPC__
 #pragma upc c_code
-#endif
 
 #include "bug899.h"
 
