@@ -2,7 +2,7 @@
  * UPC runtime memory allocation functions
  *
  * Jason Duell <jcduell@lbl.gov>
- * $Id: upcr_alloc.c,v 1.109 2013/08/08 00:41:35 phargrov Exp $
+ * $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_alloc.c $
  *
  */
 
@@ -679,7 +679,7 @@ upcr_shared_ptr_t _upcr_local_alloc(size_t nblocks, size_t blocksz UPCRI_PT_ARG)
     if (!upcr_getenv("UPC_NO_DEPRECATED")) {
       char loc[500] = { '\0', };
       upcri_append_srcloc(loc, sizeof(loc));
-      upcri_warn("upc_local_alloc() will be removed in UPC 1.3.  "
+      upcri_warn("upc_local_alloc() was removed in UPC 1.3.  "
                  "Use upc_alloc() instead.  "
                  "This message appears at most once per thread and can be "
                  "silenced by setting environment variable UPC_NO_DEPRECATED.%s", loc);
