@@ -1,6 +1,4 @@
-/*   $Source: /var/local/cvs/upcr/upcr_atomic.h,v $
- *     $Date: 2012/07/11 23:58:00 $
- * $Revision: 1.46 $
+/*   $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_atomic.h $
  * Description:
  *  Berkeley UPC atomic extensions - types and prototypes 
  *
@@ -75,24 +73,22 @@ struct upcri_atomic_result {
   (isstrict ? (GASNETT_ATOMIC_MB_PRE|GASNETT_ATOMIC_MB_POST) : 0)
 
 #if UPCRI_ATOMIC_FORCE_STRONG
-  #define upcri_atomic32_t      gasnett_strongatomic32_t
-  #define upcri_atomic32_read   gasnett_strongatomic32_read
-  #define upcri_atomic32_set    gasnett_strongatomic32_set
-  #define upcri_atomic32_cas    gasnett_strongatomic32_compare_and_swap
-  #define upcri_atomic64_t      gasnett_strongatomic64_t
-  #define upcri_atomic64_read   gasnett_strongatomic64_read
-  #define upcri_atomic64_set    gasnett_strongatomic64_set
-  #define upcri_atomic64_cas    gasnett_strongatomic64_compare_and_swap
+  #define _upcri_atomic_cons(_id)  gasnett_strongatomic##_id
 #else
-  #define upcri_atomic32_t      gasnett_atomic32_t
-  #define upcri_atomic32_read   gasnett_atomic32_read
-  #define upcri_atomic32_set    gasnett_atomic32_set
-  #define upcri_atomic32_cas    gasnett_atomic32_compare_and_swap
-  #define upcri_atomic64_t      gasnett_atomic64_t
-  #define upcri_atomic64_read   gasnett_atomic64_read
-  #define upcri_atomic64_set    gasnett_atomic64_set
-  #define upcri_atomic64_cas    gasnett_atomic64_compare_and_swap
+  #define _upcri_atomic_cons(_id)  gasnett_atomic##_id
 #endif
+#define upcri_atomic32_t      _upcri_atomic_cons(32_t)
+#define upcri_atomic32_read   _upcri_atomic_cons(32_read)
+#define upcri_atomic32_set    _upcri_atomic_cons(32_set)
+#define upcri_atomic32_cas    _upcri_atomic_cons(32_compare_and_swap)
+#define upcri_atomic32_swap   _upcri_atomic_cons(32_swap)
+#define upcri_atomic32_add    _upcri_atomic_cons(32_add)
+#define upcri_atomic64_t      _upcri_atomic_cons(64_t)
+#define upcri_atomic64_read   _upcri_atomic_cons(64_read)
+#define upcri_atomic64_set    _upcri_atomic_cons(64_set)
+#define upcri_atomic64_cas    _upcri_atomic_cons(64_compare_and_swap)
+#define upcri_atomic64_swap   _upcri_atomic_cons(64_swap)
+#define upcri_atomic64_add    _upcri_atomic_cons(64_add)
 
 /* Affinity/access tests */
 GASNETT_INLINE(upcri_atomic32_local)
@@ -642,11 +638,7 @@ enum {  /* The mixed case eases some templates */
   uint32_t
   _bupc_atomicU32_fetchadd_local(void *addr, uint32_t operand, int flags) {
     upcri_atomic32_t * const p = (upcri_atomic32_t *)addr;
-    uint32_t oldval, newval;
-    do {
-      newval = (oldval = upcri_atomic32_read(p, 0)) + operand;
-    } while(!upcri_atomic32_cas(p, oldval, newval, flags));
-    return oldval;
+    return upcri_atomic32_add(p, operand, flags) - operand;
   }
 #endif
 
@@ -706,11 +698,7 @@ enum {  /* The mixed case eases some templates */
   uint32_t
   _bupc_atomicU32_swap_local(void *addr, uint32_t operand, int flags) {
     upcri_atomic32_t * const p = (upcri_atomic32_t *)addr;
-    uint32_t oldval;
-    do {
-      oldval = upcri_atomic32_read(p, 0);
-    } while(!upcri_atomic32_cas(p, oldval, operand, flags));
-    return oldval;
+    return upcri_atomic32_swap(p, operand, flags);
   }
 #endif
 
@@ -776,11 +764,7 @@ enum {  /* The mixed case eases some templates */
   uint64_t
   _bupc_atomicU64_fetchadd_local(void *addr, uint64_t operand, int flags) {
     upcri_atomic64_t * const p = (upcri_atomic64_t *)addr;
-    uint64_t oldval, newval;
-    do {
-      newval = (oldval = upcri_atomic64_read(p, 0)) + operand;
-    } while(!upcri_atomic64_cas(p, oldval, newval, flags));
-    return oldval;
+    return upcri_atomic64_add(p, operand, flags) - operand;
   }
 #endif
 
@@ -840,11 +824,7 @@ enum {  /* The mixed case eases some templates */
   uint64_t
   _bupc_atomicU64_swap_local(void *addr, uint64_t operand, int flags) {
     upcri_atomic64_t * const p = (upcri_atomic64_t *)addr;
-    uint64_t oldval;
-    do {
-      oldval = upcri_atomic64_read(p, 0);
-    } while(!upcri_atomic64_cas(p, oldval, operand, flags));
-    return oldval;
+    return upcri_atomic64_swap(p, operand, flags);
   }
 #endif
 
@@ -1161,7 +1141,7 @@ _BUPC_ATOMIC_PRIV_RMW2_DEFN(64, mswap)
 /*---------------------------------------------------------------------------------*/
 /* External interface: */
 #if !UPCRI_BUILDING_LIBUPCR
-#include <upcr_geninclude/upcr_atomic_defs.h>
+#include <upcr_atomic_defs.h>
 #endif
 
 /*---------------------------------------------------------------------------------*/
