@@ -1,6 +1,6 @@
 /*
  * UPC Collectives templates for typed interfaces
- * $Id: upcr_coll_templates.c,v 1.44 2013/06/20 00:33:21 phargrov Exp $
+ * $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_coll_templates.c $
  */
 
 /* NOTE:
@@ -982,7 +982,7 @@ UPCRI_COLL_PREFIX_REDUCE_PROTO(UPCRI_COLL_RED_TYPE,UPCRI_COLL_RED_SUFF)
 		} else if (src_th > src_aff) {
 		    my_src -= start_phase;
 		}
-		if (upcri_thread_is_local(src_th)) {
+		if (upcri_thread_is_addressable(src_th)) {
 		    UPCRI_UNALIGNED_MEMCPY(my_dst, UPCRI_COLL_LOCALIZE(my_src, src_th), nbytes);
 		} else {
 		    gasnet_get_bulk(my_dst, upcri_thread_to_node(src_th), my_src, nbytes);
