@@ -1,6 +1,4 @@
-/*   $Source: /var/local/cvs/upcr/upcr_locks.c,v $
- *     $Date: 2013/09/29 20:52:57 $
- * $Revision: 1.103.2.2 $
+/*   $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_locks.c $
  * Description: UPC lock implementation on GASNet
  * Copyright 2002, Dan Bonachea <bonachea@cs.berkeley.edu>
  */
@@ -190,11 +188,17 @@
   #undef UPCRI_LOCKS_PSHARED
 #endif
 
+#if UPCRI_USING_PSHM || (UPCRI_SYMMETRIC_SEGMENTS && !GASNET_CONDUIT_SMP)
+  #define UPCRI_LOCKS_SHARED 1
+#else
+  #define UPCRI_LOCKS_SHARED 0
+#endif
+
 #if !UPCRI_AMLOCKS
   /* Not implementing MCS locks at all */
   #undef UPCRI_LOCKS_PSHARED
   #define upcri_lllocksystem_init() ((void)0)
-#elif !(UPCRI_LOCKS_PSHARED && UPCRI_USING_PSHM)
+#elif !(UPCRI_LOCKS_PSHARED && UPCRI_LOCKS_SHARED)
   /* GASNet's HSLs only when lll cannot be in shared memory */
   #undef UPCRI_LOCKS_PSHARED
   #define upcri_lllocksystem_init() ((void)0)
@@ -442,17 +446,21 @@ GASNETT_INLINE(upcri_lock_localaddr)
 void *upcri_lock_localaddr(upcr_thread_t thread, void *addr) {
   #if !UPCRI_AMLOCKS
     upcri_err("illegal call to upcri_lock_localaddr");
+    return NULL;
   #elif UPCRI_UPC_PTHREADS || UPCRI_USING_PSHM
     const uintptr_t t2l = upcri_thread2local[thread];
     if (t2l) {
         return (void *)(t2l + ((uintptr_t)addr) UPCRI_MINUS_REMOTE_OFFSET(thread));
     }
+    return NULL;
+  #elif UPCRI_SYMMETRIC_SEGMENTS
+    return addr;
   #else
     if (thread == upcr_mythread()) {
         return addr;
     }
-  #endif
     return NULL;
+  #endif
 }
 /* -------------------------------------------------------------------------- */
 /* Given (node,thread,addr) for a lock, return localized pointer or NULL.  */
@@ -486,12 +494,15 @@ void *upcri_lock_localaddr(upcr_thread_t thread, void *addr) {
     if (t2l) {
         return (upcri_shared_lockinfo_t *) (upcri_sli_addrfield + t2l);
     }
+    return NULL;
+  #elif UPCRI_SYMMETRIC_SEGMENTS
+    return (upcri_shared_lockinfo_t *) (upcri_sli_addrfield UPCRI_PLUS_REMOTE_OFFSET(thread));
   #else
     if (thread == upcr_mythread()) {
         return upcri_auxdata()->lock_info.shared;
     }
-  #endif
     return NULL;
+  #endif
   }
 #endif
 /* Given a local thread return pointer to their lockinfo */
@@ -797,14 +808,14 @@ void upcri_SRQ_lockdestroy(gasnet_token_t token,
     upcri_lock_t *lock = (upcri_lock_t *) _lock;
     upcr_thread_t tail_thread;
     upcri_heldlock_t *tail_addr;
-  #if UPCRI_USING_PSHM
+  #if UPCRI_LOCKS_SHARED
     upcri_shared_lockinfo_t *his_sli;
   #endif
     uint32_t generation = lock->generation;
     
     upcri_doSRQ_lockdestroy(lock_threadid, lock, &tail_thread, &tail_addr);
 
-  #if UPCRI_USING_PSHM
+  #if UPCRI_LOCKS_SHARED
     his_sli = upcri_get_sharedlockinfo_or_null(freer_threadid);
     if (his_sli != NULL) {
         /* Same as upcri_doSRP_lockreply() which isn't defined yet */
@@ -1161,7 +1172,7 @@ void upcri_SRQ_lock(gasnet_token_t token,
 #else
     upcr_thread_t reply_thread;
     upcri_heldlock_t *reply_addr;
-  #if UPCRI_USING_PSHM
+  #if UPCRI_LOCKS_SHARED
     upcri_shared_lockinfo_t *his_sli;
   #endif
     upcri_lock_t * const lock = (upcri_lock_t *)_lock;
@@ -1182,7 +1193,7 @@ void upcri_SRQ_lock(gasnet_token_t token,
                        threadid, (upcri_heldlock_t *)_address,
                        &reply_thread, &reply_addr);
     }
-  #if UPCRI_USING_PSHM
+  #if UPCRI_LOCKS_SHARED
     his_sli = upcri_get_sharedlockinfo_or_null(threadid);
     if (his_sli != NULL) {
         upcri_assert(upcri_thread_to_node(threadid) != gasnet_mynode());
@@ -1238,7 +1249,7 @@ void upcri_SRQ_unlock(gasnet_token_t token,
     const int isfree = upcri_doSRQ_unlock(threadid, generation, lock);
     const int reply = (int) ( isfree ? UPCRI_UNLOCK_DONE : UPCRI_UNLOCK_PASS );
 
-  #if UPCRI_USING_PSHM
+  #if UPCRI_LOCKS_SHARED
     upcri_shared_lockinfo_t *his_sli = upcri_get_sharedlockinfo_or_null(threadid);
         if (his_sli != NULL) {
         upcri_assert(upcri_thread_to_node(threadid) != gasnet_mynode());
