@@ -3,7 +3,7 @@
  * see: Bonachea, D. "Proposal for Extending the UPC Memory Copy Library Functions"
  *  available at http://upc.lbl.gov/publications/
  *
- * $Id: upcr_memcpy.h,v 1.15 2012/07/11 23:58:00 phargrov Exp $
+ * $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_memcpy.h $
  * Dan Bonachea <bonachea@cs.berkeley.edu>
  */
 
@@ -165,12 +165,12 @@ extern bupc_handle_t _bupc_end_accessregion(UPCRI_PT_ARG_ALONE);
     GASNETT_INLINE(_upcri_smemvec_check)
     uintptr_t _upcri_smemvec_check(size_t count, bupc_smemvec_t const list[], char const *file, int line) {
       uintptr_t retval = 0;
-      int i;
+      size_t i;
       for (i=0; i < count; i++) {
         if (list[i].len > 0) {
           (void) upcri_checkvalid_shared(UPCR_BLESS_SVPI(list[i].addr));
           if (upcr_isnull_shared(UPCR_BLESS_SVPI(list[i].addr))) 
-            upcri_err("NULL address in bupc_smemvec_t list, at entry %i, at %s:%i", i, file, line);
+            upcri_err("NULL address in bupc_smemvec_t list, at entry %lu, at %s:%i", (unsigned long)i, file, line);
           retval += list[i].len;
         }
       }
@@ -179,11 +179,11 @@ extern bupc_handle_t _bupc_end_accessregion(UPCRI_PT_ARG_ALONE);
     GASNETT_INLINE(_upcri_pmemvec_check)
     uintptr_t _upcri_pmemvec_check(size_t count, bupc_pmemvec_t const list[], char const *file, int line) {
       uintptr_t retval = 0;
-      int i;
+      size_t i;
       for (i=0; i < count; i++) {
         if (list[i].len > 0) {
           if (list[i].addr == NULL) 
-            upcri_err("NULL address in bupc_pmemvec_t list, at entry %i, at %s:%i", i, file, line);
+            upcri_err("NULL address in bupc_pmemvec_t list, at entry %lu, at %s:%i", (unsigned long)i, file, line);
           retval += list[i].len;
         }
       }
@@ -251,22 +251,22 @@ extern bupc_handle_t _bupc_end_accessregion(UPCRI_PT_ARG_ALONE);
   #if UPCR_DEBUG
     GASNETT_INLINE(_upcri_slist_check)
     uintptr_t _upcri_slist_check(size_t count, upcr_shared_ptr_t const *list, size_t len, char const *file, int line) {
-      int i;
+      size_t i;
       if (len == 0) upcri_err("illegal zero length at at %s:%i", file, line);
       for (i=0; i < count; i++) {
         (void) upcri_checkvalid_shared(list[i]);
         if (upcr_isnull_shared(list[i])) 
-          upcri_err("NULL address in address list, at entry %i, at %s:%i", i, file, line);
+          upcri_err("NULL address in address list, at entry %lu, at %s:%i", (unsigned long)i, file, line);
       }
       return ((uintptr_t)count)*len;
     }
     GASNETT_INLINE(_upcri_plist_check)
     uintptr_t _upcri_plist_check(size_t count, const void * const *list, size_t len, char const *file, int line) {
-      int i;
+      size_t i;
       if (len == 0) upcri_err("illegal zero length at at %s:%i", file, line);
       for (i=0; i < count; i++) {
         if (list[i] == NULL) 
-          upcri_err("NULL address in address list, at entry %i, at %s:%i", i, file, line);
+          upcri_err("NULL address in address list, at entry %lu, at %s:%i", (unsigned long)i, file, line);
       }
       return ((uintptr_t)count)*len;
     }
@@ -436,7 +436,7 @@ extern bupc_handle_t _bupc_end_accessregion(UPCRI_PT_ARG_ALONE);
     size_t _upcri_scheck_strided(upcr_shared_ptr_t addr, size_t const *strides, size_t const *count, size_t stridelevels, char const *file, int line) {
       int i;
       size_t sz = count[0];
-      for (i=0; i < stridelevels; i++) {
+      for (i=0; i < (int)stridelevels; i++) {
         if (strides[i] < sz)
           upcri_err("illegal stride[%i]=%i at %s:%i", i, (int)strides[i], file, line);
         sz *= count[i+1];
@@ -450,7 +450,7 @@ extern bupc_handle_t _bupc_end_accessregion(UPCRI_PT_ARG_ALONE);
     size_t _upcri_pcheck_strided(const void *addr, size_t const *strides, size_t const *count, size_t stridelevels, char const *file, int line) {
       int i;
       size_t sz = count[0];
-      for (i=0; i < stridelevels; i++) {
+      for (i=0; i < (int)stridelevels; i++) {
         if (strides[i] < sz)
           upcri_err("illegal stride[%i]=%i at %s:%i", i, (int)strides[i], file, line);
         sz *= count[i+1];
