@@ -7,6 +7,10 @@
 
 #include <upc.h>
 
+#ifndef SIZEOF_INT
+#include <upcr_config.h>
+#endif
+
 /* 
  * Non-standard Berkeley UPC extensions 
  */
@@ -19,6 +23,9 @@
   }
   #undef upc_poll
   #define upc_poll bupc_poll
+#else
+  extern void upc_poll(void);
+  extern void bupc_poll(void);
 #endif
 
 /* Loads a null-terminated string description of a shared pointer into a
