@@ -1,7 +1,7 @@
 /*
  * Functions for accessing shared memory
  *
- * $Id: upcr_shaccess.h,v 1.82 2013/09/13 19:48:28 bonachea Exp $
+ * $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_shaccess.h $
  * Jason Duell <jcduell@lbl.gov>
  */
 
@@ -26,7 +26,7 @@
         if (_nbytes <= 16) {                                                  \
            char *_p_out = _data_tmp; int _i;                                  \
            strcpy(_p_out,"  data: "); _p_out += strlen(_p_out);               \
-           for (_i = 0; _i < _nbytes; _i++) {                                 \
+           for (_i = 0; _i < (int)_nbytes; _i++) {                            \
              snprintf(_p_out,4,"%02x ", (unsigned int)_src[_i]); _p_out += 3; \
            }                                                                  \
         }                                                                     \
@@ -311,19 +311,15 @@ void *_upcr_pshared_to_processlocal(upcr_pshared_ptr_t sptr UPCRI_TV_ARG) {
 GASNETT_INLINE(_bupc_castable)
 int _bupc_castable(upcr_shared_ptr_t sptr) {
   (void) upcri_checkvalid_shared(sptr);
- #if UPCRI_BUPC_CAST_PROCESS_SCOPE
-  return (upcri_s_nodeof(sptr) == gasnet_mynode()) || upcr_isnull_shared(sptr);
- #else
+#if UPCRI_SYMMETRIC_SEGMENTS
+  return 1;
+#else
   return upcri_s_islocal(sptr) || upcr_isnull_shared(sptr);
- #endif
+#endif
 }
 GASNETT_INLINE(_bupc_thread_castable)
 int _bupc_thread_castable(unsigned int thr) {
- #if UPCRI_BUPC_CAST_PROCESS_SCOPE
-  return (upcri_thread_to_node(thr) == gasnet_mynode());
- #else
-  return upcri_thread_is_local(thr);
- #endif
+  return upcri_thread_is_addressable(thr);
 }
 GASNETT_INLINE(_bupc_cast)
 void *_bupc_cast(upcr_shared_ptr_t sptr) {
