@@ -1285,7 +1285,7 @@ _upcr_add_shared(upcr_shared_ptr_t sptr, size_t elemsz, ptrdiff_t inc,
       out_phase = phase_plus;
       out_thread = sptr_thread;
       block_incr = 0;
-      if (phase_plus == blockelems) { /* Wrap */
+      if (phase_plus == (ptrdiff_t)blockelems) { /* Wrap */
         out_phase = 0;
         if (++out_thread == numthreads) { /* Wrap */
           out_thread = 0;
