@@ -3,7 +3,7 @@
  *
  * Jason Duell <jcduell@lbl.gov>
  *
- * $Id: upcr_threads.h,v 1.88 2013/03/06 04:59:17 phargrov Exp $
+ * $Source: bitbucket.org:berkeleylab/upc-runtime.git/upcr_threads.h $
  */
 
 #ifndef UPCR_THREADS_H
@@ -472,10 +472,24 @@ extern upcr_thread_t upcri_mynode;
     (gasnet_node_t)(threadid))
 #endif
 
+/* thread is member of my gasnet node */
 GASNETT_INLINE(upcri_thread_is_local)
 int upcri_thread_is_local(upcr_thread_t thread)
 {
-#if UPCRI_UPC_PTHREADS || UPCRI_USING_PSHM
+#if UPCRI_UPC_PTHREADS
+    return upcri_thread2local[thread] != 0;
+#else
+    return thread == gasnet_mynode();
+#endif
+}
+
+/* thread is reachable by load/store */
+GASNETT_INLINE(upcri_thread_is_addressable)
+int upcri_thread_is_addressable(upcr_thread_t thread)
+{
+#if UPCRI_SYMMETRIC_SEGMENTS
+    return 1;
+#elif UPCRI_UPC_PTHREADS || UPCRI_USING_PSHM
     return upcri_thread2local[thread] != 0;
 #else
     return thread == gasnet_mynode();
