@@ -47,7 +47,7 @@ my %conf = (
     enable_fca_by_default   => '',
     enable_fca              => 0
 );
-my (@all_conduits) = ('mpi', 'udp', 'smp', 'ibv', 'shmem', 'portals4', 'gemini', 'aries', 'dcmf', 'pami', 'mxm');
+my (@all_conduits) = ('mpi', 'udp', 'smp', 'ibv', 'shmem', 'portals4', 'gemini', 'aries', 'pami', 'mxm');
 foreach (@all_conduits) {
     $conf{$_."_spawn"}       = 'nodefault';
     $conf{$_."_spawn_nodes"} = '';
@@ -338,8 +338,7 @@ Options:
             megabytes; use '2GB' to request 2 gigabytes.
     -[no]trace
             Enable tracing. This option is only effective if the
-            executable was build against a runtime with tracing
-            enabled.
+            executable was built with tracing enabled.
     -traceall
             Enable tracing of all events, including low-level events
             that are unnecessary for upc_trace. May impose significant
@@ -646,6 +645,9 @@ sub initialize
 	if (@args_out);
     @args_out = getOpts(0, @ARGV);
 
+    unless (grep { /$conduit/ } @conduits or $opt_infoonly) {
+        die "'$exename' was compiled for an unsupported network conduit: '$conduit'\n";
+    }
 
     $opt_verboseexpansion = $opt_verbose; # only expand %V to -v if the user passed -v
     $opt_verbose = 1 if ($opt_showonly);
@@ -1231,9 +1233,6 @@ sub parseExecutable {
   } else {
     die "'$exename' is missing network conduit information\n";
   }
-  unless (grep { /$conduit/ } @conduits ) {
-      die "'$exename' was compiled for an unsupported network conduit: '$conduit'\n";
-  }
 
   $gasnet_trace = ($gasnetlib_ctuple =~ ",trace");
   $gasnet_stats = ($gasnetlib_ctuple =~ ",stats");
